#
# spec file for package python-django-countries
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-django-countries
Version:        7.6.1
Release:        1.3
Summary:        Provides a country field for Django models
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/SmileyChris/django-countries/
Source:         https://files.pythonhosted.org/packages/source/d/django-countries/django-countries-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Django
Requires:       python-typing-extensions
Recommends:     python-djangorestframework
Recommends:     python-graphene-django
Recommends:     python-pyuca
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module Django}
BuildRequires:  %{python_module djangorestframework}
BuildRequires:  %{python_module graphene-django}
BuildRequires:  %{python_module pytest-django}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module pyuca}
BuildRequires:  %{python_module typing-extensions}
# /SECTION
%python_subpackages

%description
Provides a country field for Django models, including
support for Django REST Framework.

%prep
%setup -q -n django-countries-%{version}
sed -i '1{/^#!/d}' django_countries/*.py

%build
%pyproject_wheel

%install
%pyproject_install
%{python_expand rm -r %{buildroot}%{$python_sitelib}/django_countries/tests/
%fdupes %{buildroot}%{$python_sitelib}
}

%check
export DJANGO_SETTINGS_MODULE=django_countries.tests.settings
export PYTHONPATH=${PWD}
%pytest

%files %{python_files}
%doc CHANGES.rst README.rst
%license LICENSE
%{python_sitelib}/django_countries
%{python_sitelib}/django_countries-%{version}.dist-info

%changelog
* Sun Apr  7 2024 Dirk Müller <dmueller@suse.com>
- update to 7.6.1:
  * Fix a TypeError when no country is selected, introduced in
    the Django 5 fix.
  * Replace deprecated pkg_resources.iter_entry_points with
    importlib_metadata.
  * Support Django 5.0.
* Wed Nov 29 2023 Dirk Müller <dmueller@suse.com>
- update to 7.5.1:
  * Make ``CountryField`` queryset filters also work with country
    codes in addition to names.
  * Switch to ``pyproject.toml`` rather than ``setup.py`` to fix
    installation issues with pip 23.0+.
  * Rename Turkey to Türkiye.
  * Improve translation fallback handling, fixing a threading
    race condition that could cause odd translation issues.
  * This also fixes translation issues with older Python 3.6/3.7
    versions.
  * Add Python 3.11, drop Python 3.6 and Django 2.2 support.
  * Fix error when using ``USE_I18N = False``.
  * Fix broken translations due to last common country names fix.
  * Fixed Traditional Chinese translation (needed to be
    ``locale/zh_Hant``).
  * Update flag of Honduras.
  * Add Django 4.0 and 4.1 to the test matrix, dropping 3.0 and
    3.1
  * Add Django Rest Framework 3.13 and 3.14, dropping 3.11.
  * Multi-choice countries are now stored sorted and with
    duplicates stripped.
  * Fix common country names not being honoured in non-English
    translations (only fixed for Python 3.8+).
  * Fix slowdown introduced in v7.3 caused by always using
    country name lookups for field comparisons.
    ``filter(country="New Zealand")`` will no longer match now,
    but instead new ``__name`` and ``__iname`` filters have
    been added to achieve this.
  * Typing compatibility fixes for Python <3.9.
  * Make full English country names work in database lookups, for
    example, ``Person.objects.filter(country__icontains="zealand")``.
* Tue May 11 2021 John Vandenberg <jayvdb@gmail.com>
- Add optional dependency pyuca
- Update to v7.2.1
  * Fix Latin translations.
- from v7.2
  * Allow the character field to work with custom country codes that
    are not 2 characters (such as "GB-WLS").
  * Fix compatibility with django-migrations-ignore-attrs library.
- from v7.1
  * Allow customising the str_attr of Country objects returned from
    a CountryField via a new countries_str_attr keyword argument
  * Add pyuca as an extra dependency, so that it can be installed
    like pip install django-countries[pyuca].
  * Add Django 3.2 support.
- from v7.0
  * Add name_only as option to the DRF serializer field
  * Add in Python typing.
  * Add Python 3.9, Django 3.1, and Django Rest Framework 3.12 support
  * Drop Python 3.5 support.
  * Improve IOC code functionality, allowing them to be overridden in
    COUNTRIES_OVERRIDE using the complex dictionary format.
- from v6.1.3
  * Update flag of Mauritania.
  * Add flag for Kosovo (under its temporary code of XK)
* Sat Jun  6 2020 John Vandenberg <jayvdb@gmail.com>
- Update to v6.1.2
* Thu Apr 18 2019 John Vandenberg <jayvdb@gmail.com>
- Convert to single spec, fdupes, tidy
- Add Obsoletes/Provides for old Python 2 package name
- Remove tests from runtime package, fix hashbangs
- Use %%license, add CHANGES.rst to %%doc
- Update to v5.3.3
* Fri Sep 27 2013 p.drouand@gmail.com
- Update to version 1.5
  + No changelog available
- Replace python-distribute with python-setuptools BuildRequires
* Mon Oct 15 2012 jfunk@funktronics.ca
- Update to 1.4:
  * Added and updated translations
  * Updated country list (Libya changed)
- Run tests
- Add LICENSE to %%doc
- README is now README.rst
* Sat Oct  8 2011 alexandre@exatati.com.br
- Update to 1.1.1:
  - Sorry, no changelog.
* Thu Oct  6 2011 alexandre@exatati.com.br
- Update to 1.1;
- Regenerate spec file with p2pack.
* Thu Jan 22 2009 poeml@suse.de
- initial package (0.1-r3)
